@@ -4,17 +4,17 @@
 modname = "rqlcontroller"
 distname = "cubicweb-rqlcontroller"
 
-numversion = (0, 8, 2)
+numversion = (0, 9, 0)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
 author = "LOGILAB S.A. (Paris, FRANCE)"
 author_email = "contact@logilab.fr"
 description = "restfull rql edition capabilities"
-web = "http://www.cubicweb.org/project/%s" % distname
+web = "https://forge.extranet.logilab.fr/cubicweb/cubes/%s" % distname
 
 __depends__ = {
-    "cubicweb": ">= 3.32.2",
+    "cubicweb": ">= 3.32.2, < 3.34.0",
 }
 __recommends__ = {}
 
